@@ -46,10 +46,23 @@ def main():
                                       exc.to_html(),
                                       QtGui.QMessageBox.Ok)
             sys.exit()
-        from PyQt4 import QtCore
-        translator = QtCore.QTranslator()
-        translator.load("scribo_ru.qm")
-        app.installTranslator(translator)
+        #from PyQt4 import QtCore
+        #translator = QtCore.QTranslator()
+        #translator.load("scribo_ru.qm")
+        #app.installTranslator(translator)
+        import locale, os
+        mylocale = locale.getdefaultlocale()[0]
+        print "scribo_" + mylocale + ".qm"
+        if mylocale == None:
+            pass
+        else:
+            print "scribo_" + mylocale + ".qm"
+            if os.path.isfile("scribo_" + mylocale + ".qm"):
+                from PyQt4 import QtCore
+                translator = QtCore.QTranslator()
+                translator.load("scribo_" + mylocale + ".qm")
+                app.installTranslator(translator)
+
         from ui.MainWindow import main_window
         from ConfigDriver import config
 
