@@ -107,7 +107,7 @@ class LivejAccount(Account, Service):
         @return None 
         """
 
-        value = value.replace('-', '_').lower()
+        value = str(value).replace('-', '_').lower()
         super(LivejAccount, self).set_username(value)
 
 
