@@ -7,16 +7,15 @@
   @date: 11.12.2009
 """
 
-import sys
-#sys.path.append("./src/services")
-#sys.path.append("./src/ldm")
-
 
 from PyQt4 import QtCore
 from PyQt4 import QtGui
 
 from MainWindow import main_window
 from ToolbarWindow import ToolbarWindow
+from ldm.Profile import *
+from ldm.Account import *
+from services.LivejAccount import *
 
 __author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
 __version__ = "$Revision: 0.1 $"
@@ -39,6 +38,8 @@ class AddPostWindow(ToolbarWindow):
 
         self.tags = None
         self.msg = msg
+        self.is_change = False
+        self.start_text = ""
         QtGui.QWidget.__init__(self, parent.centralWidget())
 
         self.vbox_add = QtGui.QVBoxLayout()
@@ -48,17 +49,18 @@ class AddPostWindow(ToolbarWindow):
         first_toolbar = self.create_toolbar()
         second_toolbar = self.create_toolbar_second()
 
-        title_label = QtGui.QLabel(self.tr("Title"), self)
+        title_label = QtGui.QLabel(self.tr("Subject"), self)
         title_label.setAlignment(QtCore.Qt.AlignLeft)
-        text_label = QtGui.QLabel(self.tr("Text a new post"), self)
-        text_label.setAlignment(QtCore.Qt.AlignLeft)
+        #text_label = QtGui.QLabel(self.tr("Text a new post"), self)
+        #text_label.setAlignment(QtCore.Qt.AlignLeft)
 
         self.text_edit = QtGui.QTextEdit(self)
         self.title_edit = QtGui.QLineEdit(self)
         self.title_edit.setMaxLength(100)
         if msg:
             self.text_edit.insertPlainText(msg.text)
-            text_label.setText(self.tr("Text a editing post"))
+            self.start_text = msg.text
+            #text_label.setText(self.tr("Text a editing post"))
             title = msg.title
             if not msg.title:
                 title = ""
@@ -66,12 +68,14 @@ class AddPostWindow(ToolbarWindow):
         self.title_edit.setFocus()
 
         self.hbox_all.addWidget(first_toolbar)
+        self.hbox_all.addSpacing(5)
         self.vbox_add.addWidget(title_label)
         self.vbox_add.addWidget(self.title_edit)
-        self.vbox_add.addWidget(text_label)
+        #self.vbox_add.addWidget(text_label)
         self.vbox_add.addWidget(self.text_edit)
 
         self.hbox_all.addLayout(self.vbox_add)
+        self.hbox_all.addSpacing(5)
         self.hbox_all.addWidget(second_toolbar)
         self.setLayout(self.hbox_all)
 
@@ -103,32 +107,34 @@ class AddPostWindow(ToolbarWindow):
         @return
         """
 
-        self.pict_act = QtGui.QAction(self.tr("&Picture"), self)
-        #self.pict_act.setStatusTip(self.tr("Add Picture"))
+        self.pict_act = QtGui.QAction(self.tr("&Add image"), self)
         self.pict_act.setIcon(QtGui.QIcon("../data/picture.png"))
+        self.pict_act.setIconText(self.tr("Add image"))
+        #self.pict_act.setToolTip(self.tr("Add Picture"))
+        #self.pict_act.setText(self.tr("Add Picture"))
         self.connect(self.pict_act, QtCore.SIGNAL("triggered()"),
                      self.pict_post)
 
-        self.link_act = QtGui.QAction(self.tr("&Link"), self)
+        self.link_act = QtGui.QAction(self.tr("&Add URL"), self)
         #self.link_act.setStatusTip(self.tr("Add link"))
         self.link_act.setIcon(QtGui.QIcon("../data/link.png"))
         self.connect(self.link_act, QtCore.SIGNAL("triggered()"),
                      self.link_post)
 
-        self.other_act = QtGui.QAction(self.tr("&HTML"), self)
+        self.other_act = QtGui.QAction(self.tr("&HTML tags"), self)
         #self.other_act.setStatusTip(self.tr("Other HTML tags"))
         self.other_act.setIcon(QtGui.QIcon("../data/add.png"))
         self.connect(self.other_act, QtCore.SIGNAL("triggered()"),
                      self.other_post)
 
-        self.option_act = QtGui.QAction(self.tr("&Option"), self)
+        self.option_act = QtGui.QAction(self.tr("&Specials"), self)
         #self.option_act.setStatusTip(self.tr("Adding option"))
         self.option_act.setIcon(QtGui.QIcon("../data/property.png"))
         self.connect(self.option_act, QtCore.SIGNAL("triggered()"),
                      self.option_post)
 
 
-        self.send_act = QtGui.QAction(self.tr("&Send"), self)
+        self.send_act = QtGui.QAction(self.tr("&Send to.."), self)
         #self.send_act.setStatusTip(self.tr("Send post"))
         self.send_act.setIcon(QtGui.QIcon("../data/ok.png"))
         if not self.msg:
@@ -139,22 +145,31 @@ class AddPostWindow(ToolbarWindow):
                          self.edit_post)
 
         super(AddPostWindow, self).create_actions()
+        self.disconnect(self.back_act, QtCore.SIGNAL("triggered()"),
+                     main_window.back_window)
+        self.connect(self.back_act, QtCore.SIGNAL("triggered()"),
+                     self.back_window)
+        self.disconnect(self.home_act, QtCore.SIGNAL("triggered()"),
+                     main_window.home_window)
+        self.connect(self.home_act, QtCore.SIGNAL("triggered()"),
+                     self.home_window)
 
     def send_post(self):
         """ 
         handler for button OK
         @return
         """
-        if (self.text_edit.toPlainText() == ""):
+        text_post = QtCore.QString(unicode(self.text_edit.toPlainText())).trimmed()
+        if (text_post == ""):
             ret = QtGui.QMessageBox.critical(self, self.tr("Scribo"),
-                               self.tr("Please, fill text of post!"),
+                               self.tr("The post is empty!"),
                                QtGui.QMessageBox.Ok)
             return
 
         if (self.title_edit.text() == ""):
             ret = QtGui.QMessageBox.question(self, self.tr("Scribo"),
-                               self.tr("Do you want send post"\
-                                       " with empty title?"),
+                               self.tr("Do you want to send post"\
+                                       " with empty subject?"),
                                QtGui.QMessageBox.Yes,
                                QtGui.QMessageBox.No)
             if (ret == QtGui.QMessageBox.No):
@@ -162,11 +177,11 @@ class AddPostWindow(ToolbarWindow):
 
         mes = Message()
         mes.title = unicode(self.title_edit.text())
-        mes.text = unicode(self.text_edit.toPlainText())
+        mes.text = unicode(text_post)
         if self.tags:
             mes.tags = unicode(self.tags)
 
-        from ui.RepeatPost import *
+        from ui.RepeatPost import RepeatPost
         rep_post = RepeatPost(main_window, mes)
         main_window.push_window(rep_post)
 
@@ -176,16 +191,17 @@ class AddPostWindow(ToolbarWindow):
         handler for button OK
         @return
         """
-        if (self.text_edit.toPlainText() == ""):
+        text_post = QtCore.QString(unicode(self.text_edit.toPlainText())).trimmed()
+        if text_post == "":
             ret = QtGui.QMessageBox.critical(self, self.tr("Scribo"),
-                               self.tr("Please, fill text of post!"),
+                               self.tr("The post is empty!"),
                                QtGui.QMessageBox.Ok)
             return
 
         if (self.title_edit.text() == ""):
             ret = QtGui.QMessageBox.question(self, self.tr("Scribo"),
-                               self.tr("Do you want send post"\
-                                       " with empty title?"),
+                               self.tr("Do you want to send post"\
+                                       " with empty subject?"),
                                QtGui.QMessageBox.Yes,
                                QtGui.QMessageBox.No)
             if (ret == QtGui.QMessageBox.No):
@@ -193,7 +209,7 @@ class AddPostWindow(ToolbarWindow):
 
         mes = self.msg.copy()
         mes.title = unicode(self.title_edit.text())
-        mes.text = unicode(self.text_edit.toPlainText())
+        mes_text = unicode(text_post)
         if self.tags:
             mes.tags = unicode(self.tags)
         #else:
@@ -221,11 +237,13 @@ class AddPostWindow(ToolbarWindow):
 
         msg = QtGui.QMessageBox()
         uri_edit = QtGui.QLineEdit(msg)
-        uri_edit.setText("http://")
+        #msg.layout().setSizeConstraint(QtGui.QLayout.SetMaximumSize)
+        #uri_edit.setSizeIncrement(100, 100)
+        #uri_edit.setText("http://")
         msg.setWindowTitle(self.tr("Add picture"))
-        title_label = QtGui.QLabel(self.tr("Type link on the picture in web"), msg)
-        msg.layout().addWidget(title_label, 0, 0, 1, 3, QtCore.Qt.AlignLeft)
-        msg.layout().addWidget(uri_edit, 1, 0, 1, 3, QtCore.Qt.AlignLeft)
+        title_label = QtGui.QLabel(self.tr("Link to the image (URL)"), msg)
+        msg.layout().addWidget(title_label, 0, 0)
+        msg.layout().addWidget(uri_edit, 1, 0)
         link_button = msg.addButton(self.tr("Add"),
                                     QtGui.QMessageBox.AcceptRole)
         cancel_button = msg.addButton(QtGui.QMessageBox.Abort)
@@ -236,8 +254,10 @@ class AddPostWindow(ToolbarWindow):
 
         if msg.clickedButton() == link_button:
             link = uri_edit.text()
-            #self.text_edit.deselect()
-            self.text_edit.insertPlainText("<img src=\"" + link + "/>")
+            if QtCore.QString(link).contains("http://", QtCore.Qt.CaseInsensitive):
+                self.text_edit.insertPlainText("<img src=\"" + link + "\"/>")
+            else:
+                self.text_edit.insertPlainText("<img src=\"http://" + link + "\"/>")
 
 
     def link_post(self):
@@ -251,15 +271,11 @@ class AddPostWindow(ToolbarWindow):
         msg = QtGui.QMessageBox()
         msg.setWindowTitle(self.tr("Add link"))
         uri_edit = QtGui.QLineEdit(msg)
-        title_edit = QtGui.QLineEdit(msg)
-        title_edit.setFocus()
-        uri_edit.setText("http://")
-        title_label = QtGui.QLabel(self.tr("Type link and address"), msg)
-        msg.layout().addWidget(title_label, 0, 0, 1, 3, QtCore.Qt.AlignLeft)
-        msg.layout().addWidget(title_edit, 1, 0, 1, 2, QtCore.Qt.AlignLeft)
-        msg.layout().addWidget(uri_edit, 2, 0, 1, 3, QtCore.Qt.AlignLeft)
-        msg.layout().setColumnStretch(0, 1)
-        msg.layout().setColumnStretch(1, 2)
+        uri_edit.setFocus()
+
+        title_label = QtGui.QLabel(self.tr("Link"), msg)
+        msg.layout().addWidget(title_label, 0, 0)
+        msg.layout().addWidget(uri_edit, 1, 0)
 
         link_button = msg.addButton(self.tr("Add"),
                                      QtGui.QMessageBox.AcceptRole)
@@ -270,11 +286,11 @@ class AddPostWindow(ToolbarWindow):
         if msg.clickedButton() == cancel_button:
             return
         if msg.clickedButton() == link_button:
-            text = title_edit.text()
             link = uri_edit.text()
-            #self.text_edit.deselect()
-            self.text_edit.insertPlainText("<a href=\"" + link + "\">"
-                                      + text + "</a>")
+            if QtCore.QString(link).contains("http://", QtCore.Qt.CaseInsensitive):
+                self.text_edit.insertPlainText("<a href=\"" + link + "\"></a>")
+            else:
+                self.text_edit.insertPlainText("<a href=\"http://" + link + "\"></a>")
 
     def other_post(self):
         '''
@@ -357,13 +373,11 @@ class AddPostWindow(ToolbarWindow):
         elif button == self.color_button:
             print "colrr"
             color_edit = QtGui.QLineEdit()
-            #color_edit.setText(self.text_edit.toPlainText())
 
             msg2 = QtGui.QMessageBox()
             title = QtGui.QLabel(self.tr("Color text"), msg2)
-            msg2.layout().addWidget(title, 0, 0, 1, 3, QtCore.Qt.AlignLeft)
-            msg2.layout().addWidget(color_edit, 1, 0, 1, 3, QtCore.Qt.AlignLeft)
-
+            msg2.layout().addWidget(title, 0, 0)
+            msg2.layout().addWidget(color_edit, 1, 0)
             color_dial_but = msg2.addButton(self.tr("Choose color"),
                                             QtGui.QMessageBox.RejectRole)
             msg2.exec_()
@@ -398,12 +412,14 @@ class AddPostWindow(ToolbarWindow):
         tags = None
         if self.msg:
             tags = self.msg.tags
+        elif self.tags:
+            tags = self.tags
         if not tags:
             tags = ""
         tag_edit.setText(tags)
-        title_label = QtGui.QLabel(self.tr("Comma separated tags"))
-        msg.layout().addWidget(title_label, 0, 0, 1, 3, QtCore.Qt.AlignLeft)
-        msg.layout().addWidget(tag_edit, 1, 0, 1, 3, QtCore.Qt.AlignLeft)
+        title_label = QtGui.QLabel(self.tr("Tags (comma separated)"))
+        msg.layout().addWidget(title_label, 0, 0)
+        msg.layout().addWidget(tag_edit, 1, 0)
         link_button = msg.addButton(self.tr("Add"),
                                     QtGui.QMessageBox.AcceptRole)
         cancel_button = msg.addButton(QtGui.QMessageBox.Abort)
@@ -416,8 +432,36 @@ class AddPostWindow(ToolbarWindow):
             self.tags = tag_edit.toPlainText()
             #self.text_edit.deselect()
 
+    def text_changed(self):
+        """
+        catch changes text edit and title
+        """
+        text_post = QtCore.QString(unicode(self.text_edit.toPlainText())).trimmed()
+        res = QtGui.QMessageBox.No
+        if self.title_edit.isModified() or self.start_text != text_post:
+            res = QtGui.QMessageBox.question(self, self.tr("Scribo"),
+                               self.tr("Post will be lost! "\
+                                   "Continue? "),
+                               QtGui.QMessageBox.Yes,
+                               QtGui.QMessageBox.No)
+        else:
+            res = QtGui.QMessageBox.Yes
+        return res
 
-from MainWindow import *
-from ldm.Profile import *
-from ldm.Account import *
-from services.LivejAccount import *
+    def back_window(self):
+        """
+        check post on changing event
+        """
+        ret = self.text_changed()
+        if (ret == QtGui.QMessageBox.No):
+                return
+        main_window.back_window()
+
+    def home_window(self):
+        """
+        check post on changing event
+        """
+        ret = self.text_changed()
+        if (ret == QtGui.QMessageBox.No):
+                return
+        main_window.back_window()
