@@ -37,12 +37,13 @@ class RepeatPost(ToolbarWindow):
         self.mes = msg
         self.tree_view = self.tree_view_acc()
         super(RepeatPost, self).create_actions()
-        title = QtGui.QLabel(self.tr("Please, choose accounts and groups for sending the post"), self)
+        title = QtGui.QLabel(self.tr("Select accounts and groups for sending"), self)
         title.setAlignment(QtCore.Qt.AlignLeft)
         toolbar = self.create_toolbar()
         self.vbox = QtGui.QVBoxLayout()
         self.hbox = QtGui.QHBoxLayout()
         self.hbox.addWidget(toolbar)
+        self.hbox.addStretch(10)
         self.vbox.addWidget(title)
         self.vbox.addWidget(self.tree_view)
         self.hbox.addLayout(self.vbox)
@@ -89,7 +90,7 @@ class RepeatPost(ToolbarWindow):
 
             child_login = QtGui.QTreeWidgetItem(login)
 
-            child_login.setFlags(child_login.flags() | QtCore.Qt.ItemIsUserCheckable|QtCore.Qt.ItemIsEnabled)
+            child_login.setFlags(child_login.flags() | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsEnabled)
             child_login.setText(1, acc.username)
 
             child_login.setData(1, QtCore.Qt.CheckStateRole, QtCore.QVariant(QtCore.Qt.Unchecked))
@@ -163,6 +164,7 @@ class RepeatPost(ToolbarWindow):
             QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                           self.tr("Please, choose accounts or groups for sending"),
                                           QtGui.QMessageBox.Yes)
+            return
 
 
         if flag_send:
