@@ -40,11 +40,11 @@ class StartPage(QtGui.QWidget):
         QtGui.QWidget.__init__(self, parent.centralWidget())
 
         login_label = QtGui.QLabel(self.tr("Login"), self)
-        login_label.setAlignment(QtCore.Qt.AlignLeft)
+        login_label.setAlignment(QtCore.Qt.AlignRight)
         pasw_label = QtGui.QLabel(self.tr("Password"), self)
-        pasw_label.setAlignment(QtCore.Qt.AlignLeft)
-        service_label = QtGui.QLabel(self.tr("Service"), self)
-        service_label.setAlignment(QtCore.Qt.AlignLeft)
+        pasw_label.setAlignment(QtCore.Qt.AlignRight)
+        service_label = QtGui.QLabel(self.tr("Blog service"), self)
+        service_label.setAlignment(QtCore.Qt.AlignRight)
 
         #from MainWindow import main_window
         parent.new_act.setDisabled(True)
@@ -159,7 +159,7 @@ class StartPage(QtGui.QWidget):
         vbox2 = QtGui.QVBoxLayout()
         image_label = QtGui.QLabel(self)
         image_label.setAlignment(QtCore.Qt.AlignCenter)
-        start_label = QtGui.QLabel(self.tr("<i>Welcome to Scribo!</i>"), self)
+        start_label = QtGui.QLabel(self.tr("<i>Welcome to Scribo,</br> mobile multiblog client!</i>"), self)
         start_label.setAlignment(QtCore.Qt.AlignCenter)
         upic = QtGui.QImage(self.tr("../data/Scribo.png"))
         image_label.setPixmap(QtGui.QPixmap.fromImage(upic))
